package cn.iocoder.yudao.module.jx.mapper;

import cn.iocoder.yudao.module.jx.domain.DriveSchoolInsurance;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 保险管理Mapper接口
 *
 * @author ruoyi
 * @date 2024-05-06
 */
@Mapper
public interface DriveSchoolInsuranceMapper
{
    /**
     * 查询保险管理
     *
     * @param id 保险管理主键
     * @return 保险管理
     */
    public DriveSchoolInsurance selectDriveSchoolInsuranceById(Long id);

    /**
     * 查询保险管理列表
     *
     * @param driveSchoolInsurance 保险管理
     * @return 保险管理集合
     */
    public IPage<DriveSchoolInsurance> selectDriveSchoolInsuranceList(@Param("entity") DriveSchoolInsurance driveSchoolInsurance, Page<DriveSchoolInsurance> page);

    /**
     * 新增保险管理
     *
     * @param driveSchoolInsurance 保险管理
     * @return 结果
     */
    public int insertDriveSchoolInsurance(DriveSchoolInsurance driveSchoolInsurance);

    /**
     * 修改保险管理
     *
     * @param driveSchoolInsurance 保险管理
     * @return 结果
     */
    public int updateDriveSchoolInsurance(DriveSchoolInsurance driveSchoolInsurance);

    /**
     * 删除保险管理
     *
     * @param id 保险管理主键
     * @return 结果
     */
    public int deleteDriveSchoolInsuranceById(Long id);

    /**
     * 批量删除保险管理
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDriveSchoolInsuranceByIds(Long[] ids);
}
